<?  
/*  "QuiltShow 1.0" - Quilt Show registration and management software.  

Copyright 2015, 2016, 2017, 2019, 2021  by Steven K. Silber.  All Rights Reserved.
        
  This file is part of the QuiltShow program is free software: you may redistribute 
it and/or modify it under the terms of the GNU General Public License  as published
by the Free Software Foundation, either version 3 of the License, or (at your option) 
any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; 
without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  
See the GNU General Public License for more details.

There is a copy of the GNU General Public License in the 'Documentation' folder of
the distribution bundle included with this program.  

If not, see https://www.gnu.org/licenses  for a full copy of the license.  */

require('FPDF18/fpdf.php');
require_once('utilities.php');
$db=opendb_RO();  /* Open the information database - it will have 3 tables, showinfo, users, quilts) - and do error checking */
 
 $squery="SELECT * FROM showdata where  active is true";
$sresult=mysqli_query($db,$squery);
  if (!$sresult) {echo "Error fetching Show Information showdata table: " . mysqli_error($db);} 
else { $srows=mysqli_num_rows($sresult);
       $sdata=mysqli_fetch_assoc($sresult);
       $ShowYear=$sdata['ShowYear'];
       $ShowName=$sdata['ShowName'];
       $ShowDates=$sdata['ShowDates']; }


$disclaimer="By submitting this form and entry, I agree to honor the rules of the show and to accept the decisions of the judges as final.  I understand that the Blue Bonnet Quilt Guild will take every precaution to safeguard the quilts during the show, but the Blue Bonnet Quilt Guild is not responsible for any loss or damage.";

$bottom_margin=25;
$image_width=90;
$rowsize=6;
$pdf = new FPDF('p','mm','letter');
$pdf->AliasNbPages();
$pdf->SetAutoPageBreak('true',10);
$pdf->SetMargins(10,10,10);
$page_width=$pdf->GetPageWidth();
$page_height=$pdf->GetPageHeight();

$query="SELECT * from  Combined_Tables where withdrawn='no' order by lname, fname, gallery";  
// echo $query;  
$result=mysqli_query($db,$query);
if (!@$result) {echo "Failed to fetch registration information from Combined Tables: " . mysqli_error($db); }
while ($data=mysqli_fetch_assoc($result)) {

$pdf->AddPage();
// $pdf->SetFont('Times','',12); // 4.25 mm
$pdf->SetFont('Times','B',18); // 6.35 mm

$pdf->Cell(0,8,$Guild,0,1,'C');
$pdf->SetFont('Times','I',18);
$pdf->Cell(0,8,$ShowName,0,1,'C');
$pdf->SetFont('Times','',18);
$pdf->Cell(0,8,$ShowYear." Quilt Show Entry Form",0,0,'C'); $pdf->Ln(12);
$pdf->SetFont('Times','',12); 

$image="./images/quilts${ShowYear}/${data['picture']}";
//echo $image;
$x=$pdf->GetX();
$y=$pdf->GetY();
$pdf->SetXY(10,5);
$pdf->Cell(50,5,"Gallery=${data['gallery']}",0,0,'L');
$pdf->Cell(0,5,"Index=${data['idx']}",0,1,'R');
$pdf->SetXY($x,$y);

$max_image_height=$page_height-$y-110;
$isize=getimagesize($image); 
$iwidth=$isize[0]; $iheight=$isize[1];
$image_height=$image_width*$iheight/$iwidth;
if ($image_height>$max_image_height) {$image_height=$max_image_height; $image_width=$image_height*$iwidth/$iheight;}

$pdf->Image($image,$page_width-$image_width-10,$y,$image_width,0);
if (empty($data['addr2'])) {$rowsize=$image_height/9;} else {$rowsize=$image_height/10;}
$w1=40; $w2=$page_width-20-$image_width-$w1;

$pdf->SetFont('Times','B',12);  $pdf->Cell($w1,$rowsize,"Shown By: ",0,0,'R'); 
    $pdf->SetFont('Times','',12); $pdf->Cell($w2,$rowsize,"${data['fname']}  ${data['lname']}",0,1,'L');
    
$pdf->SetFont('Times','B',12);  $pdf->Cell($w1,$rowsize,"ID Number: ",0,0,'R'); 
    $pdf->SetFont('Times','',12); $pdf->Cell($w2,$rowsize,"${data['eid']}",0,1,'L');
    
$pdf->SetFont('Times','B',12);  $pdf->Cell($w1,$rowsize,"Address: ",0,0,'R');  
    $pdf->SetFont('Times','',12); $pdf->Cell($w2,$rowsize,"${data['addr1']}",0,1,'L');
    
if (!empty($data['addr2'])) {$pdf->Cell($w1,$rowsize,"",0,0,'R'); 
      $pdf->Cell($w2,$rowsize,"${data['addr2']}",0,1,'L');}

$pdf->Cell($w1,$rowsize,"",0,0,'R'); 
       $pdf->Cell($w2,$rowsize,"${data['city']},  ${data['state']}  ${data['zip']}",0,1,'L');
       
$pdf->SetFont('Times','B',12);  $pdf->Cell($w1,$rowsize,"Phone Numbers: ",0,0,'R'); 
      $pdf->SetFont('Times','',12);$pdf->Cell($w2,$rowsize,"${data['hphone']} (Home)",0,1,'L');

$pdf->Cell($w1,$rowsize,"",0,0,'R'); 
     $pdf->Cell($w2,$rowsize,"${data['cphone']}  (Cell)",0,1,'L');
     
$pdf->Cell($w1,$rowsize,"",0,0,'R'); 
     $pdf->Cell($w2,$rowsize,"${data['wphone']}  (Work)",0,1,'L');
     
$pdf->SetFont('Times','B',12); $pdf->Cell($w1,$rowsize,"E-Mail: ",0,0,'R');
      $pdf->SetFont('Times','',12);  $pdf->Cell($w2,$rowsize,"${data['email']}",0,1,'L');
      
$pdf->SetFont('Times','B',12);  $pdf->Cell($w1,$rowsize,"<?=$Gld?> Member? ",0,0,'R'); 
      $pdf->SetFont('Times','',12);  $pdf->Cell($w2,$rowsize,"${data['member']}",0,1,'L');
$pdf->Cell(0,0,'',1,0); $pdf->Ln(2);
if ($data['fee']>0) { 
        $fee_str="$".money_format('%i',$data['fee']); 
        $pdf->Write(5,"A $fee_str fee is required to complete the registration for this quilt.  See your quilts summary page for more information and a payment coupon."); 
        $pdf->Ln(5);$pdf->Cell(0,0,'',1,0); 
        $pdf->Ln(2);}
if ($data['category']=="Non-Judged Display") {
        $pdf->Write(5,"Non-Judged Display quilts will be displayed on a space available basis only."); 
        $pdf->Ln(5);$pdf->Cell(0,0,'',1,0); 
        $pdf->Ln(4);}
$x=$pdf->GetX();
$y=$pdf->GetY();
$rowsize=($page_height-$y-55)/5;
if ($rowsize>10){$rowsize=10;}
$pdf->SetFont('Times','B',12);  $pdf->Cell($w1,$rowsize,"Name of Quilt: ",0,0,'R'); 
      $pdf->SetFont('Times','I',12);$pdf->Cell($w2,$rowsize,"${data['qname']}",0,0,'L');
      
$pdf->SetFont('Times','B',12);  $pdf->Cell($w1,$rowsize,"Category: ",0,0,'R'); 
      $pdf->SetFont('Times','',12);$pdf->Cell($w2,$rowsize,"${data['category']}",0,1,'L');
     
 $pdf->SetFont('Times','B',12);  $pdf->Cell($w1,$rowsize,"Quilt Size, Length: ",0,0,'R'); 
      $pdf->SetFont('Times','',12);$pdf->Cell($w2,$rowsize,"${data['length']}",0,0,'L');
      
$pdf->SetFont('Times','B',12);  $pdf->Cell($w1,$rowsize,"Predominant Color: ",0,0,'R'); 
      $pdf->SetFont('Times','',12);$pdf->Cell($w2,$rowsize,"${data['color']}",0,1,'L');
 
 $pdf->SetFont('Times','B',12);  $pdf->Cell($w1,$rowsize,"Width: ",0,0,'R'); 
      $pdf->SetFont('Times','',12);$pdf->Cell($w2,$rowsize,"${data['width']}",0,0,'L');
      
$pdf->SetFont('Times','B',12);  $pdf->Cell($w1,$rowsize,"Who Made the Quilt? ",0,0,'R'); 
      $pdf->SetFont('Times','',12);$pdf->Cell($w2,$rowsize,"${data['makerfirst']} ${data['makerlast']}",0,1,'L');
      
$pdf->SetFont('Times','B',12);  $pdf->Cell($w1,$rowsize,"Quilting: ",0,0,'R'); 
      $pdf->SetFont('Times','',12);$pdf->Cell($w2,$rowsize,"${data['quilting']}",0,0,'L');
      
$pdf->SetFont('Times','B',12);  $pdf->Cell($w1,$rowsize,"Who Quilted the quilt? ",0,0,'R'); 
      $pdf->SetFont('Times','',12);$pdf->Cell($w2,$rowsize,"${data['quilterfirst']} ${data['quilterlast']}",0,1,'L');
    
      
$pdf->SetFont('Times','B',12);  $pdf->Cell($w1,$rowsize,"Quilt Design: ",0,0,'R'); 
      $pdf->SetFont('Times','',12);$pdf->Cell($w2,$rowsize,"${data['design']}",0,0,'L');
      
$pdf->SetFont('Times','B',12);  $pdf->Cell($w1,$rowsize,"Adaptation Source: ",0,0,'R'); 
      $pdf->SetFont('Times','',12);$pdf->Cell($w2,$rowsize,"${data['source']}",0,1,'L');
      
$pdf->SetFont('Times','B',12);  $pdf->Cell($w1,$rowsize,"Go-Texan Eligible? ",0,0,'R'); 
      $pdf->SetFont('Times','',12);$pdf->Cell($w2,$rowsize,"${data['texan']}",0,0,'L');
      
$pdf->SetFont('Times','B',12);  $pdf->Cell($w1,$rowsize,"Index Number: ",0,0,'R'); 
      $pdf->SetFont('Times','',12);$pdf->Cell($w2,$rowsize,"${data['idx']}",0,1,'L');
   
//$pdf->SetXY(10+w1+w2+5,$y);
$pdf->SetFont('Times','B',12);  $pdf->Cell(50,5,"Artist's Statement: ",0,1,'L');
$pdf->SetFont('Times','',12);$pdf->MultiCell(0,5, $data['stmt'],0,'J');

$pdf->Cell(0,0,'',1,0);  $pdf->Ln(4);
$pdf->MultiCell(0,5,$disclaimer,0,'J'); 
}

$pdf->Output('D','Entry_Form.pdf');


?>